fn const_matches(a: &TypeAnnotation, b: &TypeAnnotation) -> boolExpand description
Returns true if a is the const variant of b or vice versa (e.g. CInt <-> Int).
fn const_matches(a: &TypeAnnotation, b: &TypeAnnotation) -> boolReturns true if a is the const variant of b or vice versa (e.g. CInt <-> Int).