fn enum_matches(a: &TypeAnnotation, b: &TypeAnnotation) -> boolExpand description
Returns true if a and b are the same named tag (enum), regardless of
Enum/CEnum (mutable/const) mismatch.
fn enum_matches(a: &TypeAnnotation, b: &TypeAnnotation) -> boolReturns true if a and b are the same named tag (enum), regardless of
Enum/CEnum (mutable/const) mismatch.