fn null_array_elision(a: &TypeAnnotation, b: &TypeAnnotation) -> boolExpand description
Returns true if two array types are compatible when either inner type is Null
(i.e. an empty array [] is compatible with any typed array).
fn null_array_elision(a: &TypeAnnotation, b: &TypeAnnotation) -> boolReturns true if two array types are compatible when either inner type is Null
(i.e. an empty array [] is compatible with any typed array).